# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pacup']

package_data = \
{'': ['*']}

install_requires = \
['httpx>=0.22,<0.24',
 'packaging>=21.3,<22.0',
 'rich>=12.2.0,<13.0.0',
 'typer>=0.4.1,<0.7.0']

entry_points = \
{'console_scripts': ['pacup = pacup.__main__:main']}

setup_kwargs = {
    'name': 'pacup',
    'version': '1.0.0',
    'description': 'Help maintainers update pacscripts',
    'long_description': '<p align="center"><img alt="logo" src="https://raw.githubusercontent.com/pacstall/pacup/master/imgs/logo.png"></p>\n<h1 align="center">Pacup</h1>\n<p align="center">\n  <a href="https://www.python.org/"><img alt="Python: 3.8+" src="https://img.shields.io/badge/python-3.8%2B-306998?logo=python&logoColor=white&style=for-the-badge"></a>\n  <a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-black?style=for-the-badge"/></a>\n  <a href="https://www.codacy.com/gh/pacstall/pacup/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=pacstall/pacup&amp;utm_campaign=Badge_Grade"><img alt="Codacy: grade" src="https://img.shields.io/codacy/grade/4b1365e6f7d2474283243f62b2c5973d?label=Codacy&logo=codacy&style=for-the-badge"></a>\n  <a href="https://pypi.org/project/pacup/"><img alt="PyPI: version" src="https://img.shields.io/pypi/v/pacup?color=%233775a9&logo=pypi&logoColor=white&style=for-the-badge"></a>\n<p/>\n<p align="center">\n  <!-- Social -->\n  <a href="https://discord.gg/yzrjXJV6K8"><img alt="join discord" src="https://img.shields.io/discord/839818021207801878?color=5865F2&label=Discord&logo=discord&logoColor=FFFFFF&style=for-the-badge"></a>\n  <a href="https://reddit.com/r/pacstall"><img src="https://img.shields.io/reddit/subreddit-subscribers/pacstall?label=Reddit&color=FF4301&style=for-the-badge&logo=reddit&logoColor=FFFFFF" loading="lazy"></a>\n  <a href="https://social.linux.pizza/web/@pacstall"><img alt="Mastodon Follow" src="https://img.shields.io/mastodon/follow/107278715447740005?color=3088d4&domain=https%3A%2F%2Fsocial.linux.pizza&label=Mastodon&logo=mastodon&logoColor=white&style=for-the-badge" loading="lazy"></a>\n  <a href="https://matrix.to/#/#pacstall:matrix.org"><img alt="join matrix" src="https://img.shields.io/matrix/pacstall:matrix.org?color=888888&label=Matrix&logo=Matrix&style=for-the-badge"></a>\n<p/>\n\n## What is this?\n\nPacup (**Pac**script **Up**dater) is a maintainer helper tool to help\nmaintainers update their pacscripts. It semi-automates the tedious task of\nupdating pacscripts, and aims to make it a fun process for the maintainer!\n\n## Installation\n\nTo install the latest release run:\n\n```console\n$ pip install pacup\n```\n\nTo install the latest development build run:\n\n```console\n$ pip install git+https://github.com/pacstall/pacup\n```\n\n## Usage\n\n```console\nUsage: pacup [OPTIONS] PACSCRIPTS...\n\nUpdates specified pacscripts.\nIf ship flag is passed, the pacscript will be prepared for shipping to upstream.\nAfter the pacscript is prepared, it will be committed and pushed to the origin remote.\nThis requires you to be present in your cloned fork.\n\n╭─ Arguments ──────────────────────────────────────────────────────────────────────────────────────────╮\n│ *    pacscripts      PACSCRIPTS...  The pacscripts to update. [default: None] [required]             │\n╰──────────────────────────────────────────────────────────────────────────────────────────────────────╯\n╭─ Options ────────────────────────────────────────────────────────────────────────────────────────────╮\n│ --show-repology       -r                                       Show the parsed repology data and     │\n│                                                                exit.                                 │\n│ --debug               -d                                       Turn on debugging mode.               │\n│ --version             -v                                       Show the version and exit.            │\n│ --ship                -s                                       Prepare the pacscript for shipping to │\n│                                                                upstream.                             │\n│ --install-completion          [bash|zsh|fish|powershell|pwsh]  Install completion for the specified  │\n│                                                                shell.                                │\n│                                                                [default: None]                       │\n│ --show-completion             [bash|zsh|fish|powershell|pwsh]  Show completion for the specified     │\n│                                                                shell, to copy it or customize the    │\n│                                                                installation.                         │\n│                                                                [default: None]                       │\n│ --help                                                         Show this message and exit.           │\n╰──────────────────────────────────────────────────────────────────────────────────────────────────────╯\n```\n\nYou can get this help text by running `pacup --help`.\n\nYou should visit our [wiki](https://github.com/pacstall/pacup/wiki/Wiki), for\nmore information on how to use the `repology` key.\n\n## How does it work?\n\nSuppose `foo.pacscript` is outdated.\n\nOn running `pacup foo.pacscript` Pacup will parse the pacscript\'s variables,\nthen it compiles a list of filters specified in the `repology` variable in the\npacscript. Then it queries the [Repology API](https://repology.org/api) to get\nall the repositories which have packaged that package. After which it applies\nthe filter to the response, and from the filtrate it considers the most common\nversion to be the latest.\n\nThen it replaces all occurrences of the previous `version`\'s value in the `url`\nwith the latest one placeholder\'s value with the latest version, and downloads\nthe new package, and generates it\'s hash.\n\nThen writes the edited pacscript and installs it with\n[Pacstall](https://github.com/pacstall/pacstall), after installation it asks\nthe user to confirm that the installed package works. On approval the pacscript\nis considered successfully upgraded and the program ends.\n\n## Caveats\n\n* Does not work with `-git` pacscripts as those pacscripts are auto updating.\n* Doesn\'t work if a pacscript doesn\'t have an equivalent\n  [Repology](https://repology.org/) package.\n\n## Stats\n\n<p align="center"><img alt="Repobeats analytics image" src="https://repobeats.axiom.co/api/embed/80bc45a6d65fbfb43905aa22b3950badc09edd97.svg" /></p>\n\n## License\n\n```monospace\n    ____             __  __\n   / __ \\____ ______/ / / /___\n  / /_/ / __ `/ ___/ / / / __ \\\n / ____/ /_/ / /__/ /_/ / /_/ /\n/_/    \\__,_/\\___/\\____/ .___/\n                      /_/\n\nCopyright (C) 2022-present\n\nThis file is part of PacUp\n\nPacUp is free software: you can redistribute it and/or modify\nit under the terms of the GNU General Public License as published by\nthe Free Software Foundation, either version 3 of the License, or\n(at your option) any later version.\n\nPacUp is distributed in the hope that it will be useful,\nbut WITHOUT ANY WARRANTY; without even the implied warranty of\nMERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\nGNU General Public License for more details.\n\nYou should have received a copy of the GNU General Public License\nalong with PacUp.  If not, see <https://www.gnu.org/licenses/>.\n```\n',
    'author': 'Sourajyoti Basak',
    'author_email': 'wiz28@protonmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/pacstall/pacup',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
